トレーシング - Refinire
Author: kitfactory
Description: 複数のLLMプロバイダーに対応した統一インターフェースライブラリ

コンテンツにスキップ

# トレーシング

## OpenAI Agents SDK のトレーシング機能

OpenAI Agents SDK はデフォルトで OpenAI のトレーシングサービスを利用し、実行中のスパン情報を自動的に収集・記録します。 - プロバイダーに関わらず、内部では OpenAI の Trace API を使用します。 - `OPENAI_API_KEY` の設定が必要です。

## 本ライブラリでのアプローチ

- デフォルトでコンソール向けの `ConsoleTracingProcessor` を提供します。
- 有効化: `enable_console_tracing()` を呼び出すと、コンソールにカラー付きでスパン情報を表示します。
- トレーシングをカスタマイズしたい場合は、サードパーティーが提供する独自の Processor を使用してください。
- トレーシングを停止したい場合は、`disable_tracing()` を呼び出して全てのトレーシング機能を無効化します。

以上の仕組みにより、デバッグ時やローカル開発環境でも手軽にトレーシング情報を確認でき、必要に応じてサービス連携やログ出力先を切り替えられます。